@@ -12,6 +12,7 @@ extern "C" {
 #include "types.h"
 #include "sdbht.h"
 #include "ls.h"
+#include "dict.h"
 #include "cdb.h"
 #include "cdb_make.h"
 #include "sdb_version.h"
@@ -100,6 +101,7 @@ typedef struct sdb_t {
 	SdbKv tmpkv;
 	ut32 depth;
 	bool timestamped;
+	SdbMini mht;
 } Sdb;
 
 typedef struct sdb_ns_t {
@@ -198,8 +200,9 @@ SDB_API bool sdb_journal_clear(Sdb *s);
 SDB_API bool sdb_journal_unlink(Sdb *s);
 
 /* numeric */
-char *sdb_itoa(ut64 n, char *s, int base);
-ut64  sdb_atoi(const char *s);
+SDB_API char *sdb_itoa(ut64 n, char *s, int base);
+SDB_API ut64  sdb_atoi(const char *s);
+SDB_API const char *sdb_itoca(ut64 n);
 
 /* locking */
 SDB_API bool sdb_lock(const char *s);
@@ -209,15 +212,19 @@ SDB_API int sdb_unlink(Sdb* s);
 SDB_API int sdb_lock_wait(const char *s UNUSED);
 
 /* expiration */
-bool sdb_expire_set(Sdb* s, const char *key, ut64 expire, ut32 cas);
-ut64 sdb_expire_get(Sdb* s, const char *key, ut32 *cas);
-ut64 sdb_now(void);
-ut64 sdb_unow(void);
-ut32 sdb_hash(const char *key);
-ut32 sdb_hash_len(const char *key, ut32 *len);
+SDB_API bool sdb_expire_set(Sdb* s, const char *key, ut64 expire, ut32 cas);
+SDB_API ut64 sdb_expire_get(Sdb* s, const char *key, ut32 *cas);
+SDB_API ut64 sdb_now(void);
+SDB_API ut64 sdb_unow(void);
+SDB_API ut32 sdb_hash(const char *key);
+SDB_API ut32 sdb_hash_len(const char *key, ut32 *len);
+SDB_API ut8 sdb_hash_byte(const char *s);
 
 /* json api */
+// SDB_API int sdb_js0n(const unsigned char *js, RangstrType len, RangstrType *out);
 SDB_API bool sdb_isjson(const char *k);
+SDB_API char *sdb_json_get_str (const char *json, const char *path);
+
 SDB_API char *sdb_json_get(Sdb* s, const char *key, const char *p, ut32 *cas);
 SDB_API bool sdb_json_set(Sdb* s, const char *k, const char *p, const char *v, ut32 cas);
 SDB_API int sdb_json_num_get(Sdb* s, const char *k, const char *p, ut32 *cas);
@@ -334,7 +341,7 @@ void sdb_encode_raw(char *bout, const ut8 *bin, int len);
 int sdb_decode_raw(ut8 *bout, const char *bin, int len);
 
 // binfmt
-char *sdb_fmt(int n, const char *fmt, ...);
+char *sdb_fmt(const char *fmt, ...);
 int sdb_fmt_init(void *p, const char *fmt);
 void sdb_fmt_free(void *p, const char *fmt);
 int sdb_fmt_tobin(const char *_str, const char *fmt, void *stru);
